@@ -60,7 +60,7 @@ from cord.orm.labeling_algorithm import (
     LabelingAlgorithm, ObjectInterpolationParams, BoundingBoxFittingParams
 )
 from cord.orm.model import Model, ModelRow, ModelInferenceParams, ModelTrainingParams, ModelOperations
-from cord.orm.project import Project
+from cord.orm.project import Project, ProjectCopy
 
 # Logging configuration
 logging.basicConfig(stream=sys.stdout,
@@ -384,6 +384,31 @@ class CordClientProject(CordClient):
         """
         return self._querier.basic_getter(Project)
 
+    def copy_project(self, copy_labels=False, copy_models=False):
+        """
+        Copy the current project into a new one with copied contents including settings, datasets and users.
+        Labels and models are optional
+        Args:
+            copy_labels: currently if labels is True, all tasks with labelling will be marked as complete,
+                    otherwise all tasks will be recreated anew
+            copy_models: currently if True, all models with their training information will be copied into the new project
+
+        Returns:
+            bool
+
+        Raises:
+            AuthorisationError: If the project API key is invalid.
+            ResourceNotFoundError: If no project exists by the specified project ID.
+            UnknownError: If an error occurs while copying the project.
+        """
+
+        payload = {"copy_project_options": []}
+        if copy_labels:
+            payload["copy_project_options"].append("labels")
+        if copy_models:
+            payload["copy_project_options"].append("models")
+        return self._querier.basic_setter(ProjectCopy, self._config.resource_id, payload=payload)
+
     def get_label_row(self, uid: str, get_signed_url: bool = True):
         """
         Retrieve label row.
